==> mapcode_2.5.2.orig.tar.gz: mapcode-cpp-2.5.2/test/run_sanitizer.sh <==
#!/bin/sh
OPTS="-Wall -Werror -Wextra -Wno-pointer-to-int-cast"
LIB="../mapcodelib/mapcoder.o"

export ASAN_OPTIONS=debug=true:strict_string_checks=1:detect_stack_use_after_return=true:detect_invalid_pointer_pairs=99999:detect_container_overflow=true:detect_odr_violation=2:check_initialization_order=true:strict_init_order=true

TEST=`which clang`
if [ "$TEST" = "" ]
then
    echo "No clang found on this machine - skipping script..."
    exit 1
fi

echo "!! -------------------------------------------------------------"
echo "Run address sanitizer..."
date
echo "!! -------------------------------------------------------------"

# No optimize
echo ""
echo "Run address sanitizer with: -O0"
cd ../mapcodelib
gcc $OPTS -O0 -DDEBUG -c mapcoder.c
cd ../test
gcc $OPTS -O0 -DDEBUG unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"

# Optimize 2
echo ""
echo "Run address sanitizer with: -O2"
cd ../mapcodelib
gcc $OPTS -O2 -c mapcoder.c
cd ../test
gcc $OPTS -O2 unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"

# Optimize 3
echo ""
echo "Run address sanitizer with: -O3"
cd ../mapcodelib
gcc $OPTS -O3 -c mapcoder.c
cd ../test
gcc $OPTS -O3 unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"

echo ""
echo "Report in: $REPORT"

==> mapcode_2.5.6.orig.tar.gz: mapcode-cpp-2.5.6/test/run_sanitizer.sh <==
#!/bin/sh
#
# Copyright (C) 2014-2025 Stichting Mapcode Foundation (http://www.mapcode.com)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

OPTS="$(cat ./no_warnings.env)"
LIB="../mapcodelib/mapcoder.o"

export ASAN_OPTIONS=debug=true:strict_string_checks=1:detect_stack_use_after_return=true:detect_invalid_pointer_pairs=99999:detect_container_overflow=true:detect_odr_violation=2:check_initialization_order=true:strict_init_order=true

TEST=$(which clang)
if [ "$TEST" = "" ]
then
    echo "No clang found on this machine - skipping script..."
    exit 1
fi

echo "!! -------------------------------------------------------------"
echo "Run address sanitizer..."
date
echo "!! -------------------------------------------------------------"

# No optimize
echo ""
echo "Run address sanitizer with: -O0"
cd ../mapcodelib
gcc $OPTS -O0 -DDEBUG -c mapcoder.c
cd ../test
gcc $OPTS -O0 -DDEBUG unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"

# Optimize 2
echo ""
echo "Run address sanitizer with: -O2"
cd ../mapcodelib
gcc $OPTS -O2 -c mapcoder.c
cd ../test
gcc $OPTS -O2 unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"

# Optimize 3
echo ""
echo "Run address sanitizer with: -O3"
cd ../mapcodelib
gcc $OPTS -O3 -c mapcoder.c
cd ../test
gcc $OPTS -O3 unittest.c -lm -lpthread -fsanitize=address -o unittest $LIB
./unittest
echo "!! -------------------------------------------------------------"
